﻿Ext.require('App.Const.Finances');
Ext.define('App.Control.Kivii.Finances.Settlement.Biz.Contract.Form', {
    extend: 'System.Control.EntityForm',
    xtype: 'App.Control.Kivii.Finances.Settlement.Biz.Contract.Form',
    entityType: 'Kivii.Finances.Entities.Settlement',
    scrollable: true,
    layout: {
        type: 'responsivecolumn',
        states: {
            small: 600,
            large: 0
        }
    },
    title: '合同详情',
    iconCls: 'x-fa fa-file',
    viewModel: {
        data: {
            entity: {
                Metadata: {},
                AGAMOUNT: 0,
                AmountReport: 0,
                AmountSettled: 0,
                Kvid: null
            },
            description: ''
        },
        formulas: {
            amountChineseBig: function(get) {
                let _amount = get('entity.AGAMOUNT');
                return KiviiContext.Const.FinancesFunctionsMoneyToChineseBig(_amount);
            },
            buttonHidden: function(get) {
                let _amount = get('entity.AGAMOUNT');
                let _amountReport = get('entity.AmountReport');
                let _amountSettled = get('entity.AmountSettled');
                let _total = _amountSettled + _amountReport - _amount;
                if (_total < 0) return false;
                return true;
            }
        }
    },
    dockedItems: [{
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'menu',
        items: [{
            margin: '0 3 -10 3',
            xtype: 'displayfield',
            bind: {
                value: '{description}'
            },
            fieldStyle: {
                fontSize: '20px'
            }

        }, '->', {
            text: '结算',
            iconCls: 'x-fa fa-link',
            iconAlign: 'left',
            handler: '_onCreateSettlement',
            bind: {
                hidden: '{buttonHidden}'
            }
        }, {
            text: '完成',
            iconCls: 'x-fa fa-check',
            iconAlign: 'left',
            handler: '_onCheckContract',
            bind: {
                hidden: '{!buttonHidden}'
            }
        }]
    }],
    defaults: {
        xtype: 'textfield',
        labelWidth: 60,
        labelAlign: 'right',
        readOnly: true,
        responsiveCls: 'big-50 small-100'
    },
    items: [{
        fieldLabel: '协议编号',
        responsiveCls: 'big-30 small-100',
        bind: '{entity.ACCORDNO}'
    }, {
        fieldLabel: '企业名称',
        responsiveCls: 'big-70 small-100',
        bind: {
            value: '{entity.COMPNAME}'
        }
    }, {
        fieldLabel: '联系人',
        responsiveCls: 'big-30 small-100',
        bind: '{entity.CONTACTPERSON}'
    }, {
        fieldLabel: '联系电话',
        responsiveCls: 'big-40 small-100',
        bind: {
            value: '{entity.CONTACTPERSONPHONE}'
        }
    }, {
        fieldLabel: '协议折扣',
        responsiveCls: 'big-30 small-100',
        bind: {
            value: '{entity.DISCOUNT}'
        }
    }, {
        fieldLabel: '部门名称',
        responsiveCls: 'big-30 small-100',
        bind: '{entity.DIVISIONNAME}'
    }, {
        fieldLabel: '协议类型',
        responsiveCls: 'big-70 small-100',
        bind: {
            value: '{entity.ACCORDTYPE}'
        }
    }, {
        fieldLabel: '负责人',
        responsiveCls: 'big-30 small-100',
        bind: '{entity.SIGNER}'
    }, {
        xtype: 'datefield',
        format: 'Y-m-d',
        altFormats: 'D, d M Y H:i:s T|c|Y-m-d|Y-m-d H:i|Y/n/j',
        fieldLabel: '生效日期',
        responsiveCls: 'big-30 small-100',
        bind: {
            value: '{entity.SIGNDATE}'
        }
    }, {
        xtype: 'datefield',
        format: 'Y-m-d',
        altFormats: 'D, d M Y H:i:s T|c|Y-m-d|Y-m-d H:i|Y/n/j',
        fieldLabel: '终止日期',
        responsiveCls: 'big-40 small-100',
        bind: {
            value: '{entity.ENDDATE}'
        }
    }, {
        xtype: 'numberfield',
        fieldLabel: '协议金额',
        hideTrigger: true,
        minValue: 0,
        responsiveCls: 'big-30 small-100',
        step: 0.1,
        bind: {
            value: '{entity.AGAMOUNT}'
        }
    }, {
        xtype: 'numberfield',
        fieldLabel: '已结算额',
        hideTrigger: true,
        minValue: 0,
        responsiveCls: 'big-30 small-100',
        step: 0.1,
        bind: {
            value: '{entity.AmountSettled}'
        }
    }, {
        xtype: 'numberfield',
        fieldLabel: '未结算额',
        hideTrigger: true,
        minValue: 0,
        responsiveCls: 'big-40 small-100',
        step: 0.1,
        bind: {
            value: '{entity.AmountReport}'
        }
    }, {
        fieldLabel: '金额大写',
        responsiveCls: 'big-60 small-100',
        readOnly: true,
        bind: {
            value: '{amountChineseBig}'
        }
    }, {
        fieldLabel: '合作项目',
        responsiveCls: 'big-40 small-100',
        bind: {
            value: '{entity.PROJECTNAME}'
        }
    }, {
        xtype: 'fieldset',
        title: '已结算项目',
        collapsible: true,
        collapsed: false,
        scrollable: true,
        responsiveCls: 'big-100 small-100',
        items: [{
            xtype: 'grid',
            reference: 'settlements',
            store: {
                pageSize: 5000,
                data: [],
                groupField: 'Type',
                autoLoad: false
            },
            features: [{
                ftype: 'groupingsummary',
                groupHeaderTpl: [
                    '<div>{name:this.formatName} ({rows.length} 条)</div>',
                    {
                        formatName: function(name) {
                            if (name === "Report") {
                                return "检测费";
                            }
                            if (name === "Service") {
                                return "服务费";
                            }
                            if (name === "Express") {
                                return "快递费";
                            }
                            return name;
                        }
                    }
                ]
            }],
            dockedItems: [{
                xtype: 'toolbar',
                dock: 'top',
                overflowHandler: 'menu',
                items: [{
                    margin: '0 3 -10 3',
                    xtype: 'displayfield',
                    value: '已结算项目',
                    fieldStyle: {
                        fontSize: '20px'
                    }
                }]
            }],
            columns: {
                defaults: {
                    menuDisabled: true,
                    sortable: false
                },
                items: [{
                    xtype: 'rownumberer'
                }, {
                    dataIndex: 'BizId',
                    text: '所属业务',
                    width: 170,
                    // sortable: true,
                    summaryType: 'sum',
                    summaryRenderer: function(value, summaryData, dataIndex) {
                        return Ext.String.format('合计');
                    }
                }, {
                    dataIndex: 'PayerName',
                    text: '付款单位',
                    width: 200
                }, {
                    dataIndex: 'OperateTime',
                    text: '操作日期',
                    width: 100,
                    // sortable: true,
                    renderer: Ext.util.Format.dateRenderer('Y-m-d')
                }, {
                    dataIndex: 'Amount',
                    align: 'right',
                    text: '结算金额',
                    width: 100,
                    renderer: KiviiContext.Const.FinancesFunctionsMoneyToFmoney,
                    summaryType: 'sum',
                    summaryRenderer: function(value, summaryData, dataIndex) {
                        return Ext.String.format('￥{0}', value.toFixed(2));
                    }
                }, {
                    dataIndex: 'AmountPayment',
                    align: 'right',
                    text: '已付金额',
                    width: 100,
                    renderer: '_renderAmount',
                    summaryType: 'sum',
                    summaryRenderer: function(value, summaryData, dataIndex) {
                        return Ext.String.format('￥{0}', value.toFixed(2));
                    }
                }, {
                    dataIndex: 'OperatorName',
                    text: '操作人',
                    width: 90
                }, {
                    dataIndex: 'Remark',
                    text: '备注',
                    minWidth: 100,
                    flex: 1
                }]
            }
        }]
    }, {
        xtype: 'fieldset',
        title: '未结算报告',
        collapsible: true,
        collapsed: false,
        scrollable: true,
        responsiveCls: 'big-100 small-100',
        items: [{
            xtype: 'grid',
            reference: 'njzjReports',
            store: {
                pageSize: 5000,
                data: [],
                autoLoad: false
            },
            features: [{
                ftype: 'summary'
            }],
            dockedItems: [{
                xtype: 'toolbar',
                dock: 'top',
                overflowHandler: 'menu',
                items: [{
                    margin: '0 3 -10 3',
                    xtype: 'displayfield',
                    value: '未结算报告',
                    fieldStyle: {
                        fontSize: '20px'
                    }
                }]
            }],
            columns: {
                defaults: {
                    menuDisabled: true,
                    sortable: false
                },
                items: [{
                    xtype: 'rownumberer'
                }, {
                    dataIndex: 'FOLDERNO',
                    text: '委托单号',
                    width: 100,
                    summaryType: 'sum',
                    summaryRenderer: function(value, summaryData, dataIndex) {
                        return Ext.String.format('合计');
                    }
                }, {
                    dataIndex: 'NAME',
                    text: '样品编号',
                    width: 170
                }, {
                    dataIndex: 'COMPNAME',
                    text: '委托单位',
                    width: 150
                }, {
                    dataIndex: 'NAMEOFPRODUCTIONORG',
                    text: '生产单位',
                    width: 120
                }, {
                    dataIndex: 'SAMPLENAME',
                    text: '样品名称',
                    width: 120
                }, {
                    dataIndex: 'TOTALPRICE',
                    text: '应收费用',
                    width: 100,
                    summaryType: 'sum',
                    summaryRenderer: function(value, summaryData, dataIndex) {
                        return Ext.String.format('￥{0}', value.toFixed(2));
                    }
                }, {
                    dataIndex: 'TESTTASKNOFORCCC',
                    text: '协议编号',
                    minWidth: 100,
                    flex: 1
                }]
            }
        }]
    }, ],
    setOwner: function(_entity) {
        let _view = this;
        let _controller = _view.getController();
        _controller._readEntity(_entity);
    },
    controller: {
        _readEntity: function(_entity) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _refs = _view.getReferences();
            let _settlementsStore = _refs.settlements.getStore();
            let _njzjReportsStore = _refs.njzjReports.getStore();
            let _jsonData = {};
            _jsonData.Item = _entity;
            Ext.Ajax.request({
                url: '/Restful/Njzj.Connects.Entities.NjzjContract/Read.json',
                jsonData: _jsonData,
                success: function(_response) {
                    let _rtns = Ext.decode(_response.responseText);
                    let _description = '已结算项目:' + _rtns.Result.AmountSettled + ',未结算报告:' + _rtns.Result.AmountReport + ',已执行合同总额:' + parseFloat(_rtns.Result.AmountSettled + _rtns.Result.AmountReport);
                    _vm.set('entity', _rtns.Result);
                    _vm.set('description', _description);
                    for (let _i = 0; _i < _rtns.Result.Settlements.length; _i++) {
                        let _detail = _rtns.Result.Settlements[_i];
                        _settlementsStore.add(_detail);
                    }
                    for (let _i = 0; _i < _rtns.Result.NjzjReports.length; _i++) {
                        let _detail = _rtns.Result.NjzjReports[_i];
                        _njzjReportsStore.add(_detail);
                    }
                },
                failure: function(_response) {}
            });
        },
        //初始化成结算对象方法
        _initNewEntity: function(_entity, _includeDetail = true) {
            let _newEntity = {
                Metadata: {},
                Kvid: null,
                OffsetKvid: null,
                BizId: '',
                Amount: 0,
                AmountPlan: 0,
                AmountPayment: 0,
                Type: 'Service',
                OwnerName: KiviiContext.CurrentMember.DepartmentName,
                OwnerKvid: KiviiContext.CurrentMember.DepartmentKvid,
                OperateTime: new Date(),
                PayeeKvid: KiviiContext.CurrentMember.OrganizationKvid,
                PayeeName: KiviiContext.CurrentMember.OrganizationName,
                OperatorName: KiviiContext.CurrentMember.FullName,
                OperatorKvid: KiviiContext.CurrentMember.Kvid,
                Currency: 'CNY',
                Details: []
            };
            _newEntity.Kvid = null;
            _newEntity.Amount = parseFloat(parseFloat(_entity.AGAMOUNT - _entity.AmountReport - _entity.AmountSettled).toFixed(2));
            _newEntity.AmountPlan = parseFloat(parseFloat(_entity.AGAMOUNT - _entity.AmountReport - _entity.AmountSettled).toFixed(2));
            _newEntity.BizType = 'Kivii.Finances.Entities.Settlement';
            _newEntity.BizId = _entity.ACCORDNO;
            _newEntity.PayerName = _entity.COMPNAME;
            _newEntity.Summary = _entity.PROJECTNAME;
            for (let key in _entity) {
                if (key === 'Kvid') continue;
                _newEntity.Metadata[key] = _entity[key];
            }
            if (_includeDetail) {
                let _detail = {};
                _detail.Type = "Service";
                _detail.Quantity = 1;
                _detail.QuantityUnit = "次";
                _detail.Currency = 'CNY';
                _detail.Amount = parseFloat(parseFloat(_entity.AGAMOUNT - _entity.AmountReport - _entity.AmountSettled).toFixed(2));
                _detail.AmountPlan = parseFloat(parseFloat(_entity.AGAMOUNT - _entity.AmountReport - _entity.AmountSettled).toFixed(2));
                _detail.BizId = _entity.ACCORDNO;
                _detail.BizType = 'Njzj.Connects.Entities.NjzjContract';
                _detail.GoodsFullName = _entity.TESTNOPRICETYPE;
                _detail.GoodsSpecifications = '协议服务费用';
                _newEntity.Details.push(_detail);
            }
            return _newEntity;
        },
        _onCreateSettlement: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selected = _vm.data.entity;
            if (_selected.AGAMOUNT - _selected.AmountReport - _selected.AmountSettled <= 0) {
                Ext.toast("当前协议已执行完成,无需结算!");
                return;
            }
            let _newEntity = _controller._initNewEntity(_selected, true);
            let _form = Ext.create('App.Control.Kivii.Finances.Settlement.Form', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 1300,
                height: 720,
                modal: true,
                maximizable: true,
                resizable: true,
                items: [_form]
            });
            _win.show();
            _form.setOwner(_newEntity);
            _form.on('entityCreated', function(_ctrl, _entity) {
                _win.close();
                _controller._readEntity(_selected);
            });
        },
        _onCheckContract:function(_ctrl){
        	let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selected = _vm.data.entity;
            let _msg = Ext.create('Ext.window.MessageBox', {
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                closeAction: 'destroy'
            });
            _msg.confirm(_ctrl.text, "确认要归档当前协议合同?<br />归档后将无法继续查看此协议信息!", _controller._archiveContract, _controller);
        },
        _archiveContract: function(_optional) {
            if (_optional != "yes") {
                return;
            }
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selected = _vm.data.entity;
            let _jsonData = {};
            _jsonData.Origrec = _selected.ORIGREC;
            Ext.Ajax.request({
                url: '/Restful/Njzj.Connects.Entities.NjzjContract/Archiving.json',
                jsonData: _jsonData,
                success: function(_response) {
                    var _rtns = Ext.decode(_response.responseText);
                    _view.reload();
                    Ext.toast('合同归档成功!');
                },
                failure: function(_response) {
                    _view.reload();
                }
            });
        },
    }
});