﻿Ext.require('App.Const.Finances');
Ext.define('App.View.Kivii.Finances.Account.List', {
    extend: 'System.Control.EntityList',
    entityType: 'Kivii.Finances.Entities.Account',
    xtype: 'App.View.Kivii.Finances.Account.List',
    dataSource: '/Restful/Kivii.Finances.Entities.Account/QueryEx.json',
    title: '系统账户管理',
    iconCls: 'x-fa fa-users',
    filter: {
    	OwnerKvid:KiviiContext.CurrentMember.DepartmentKvid,
    	TypeIn:'Cash,Pos,Discount,Refund,Biz'
    },
    viewModel: {
        data: {
            _selection: null,
            lastOwnerKvid: null
        }
    },
    bind: {
        selection: '{_selection}'
    },
    store: {
        autoLoad: true,
        pageSize: 50
    },
    features: [{
        ftype: 'summary'
    }],
    dockedItems: [{
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
            xtype: 'searchField',
            flex: 1,
            minWidth: 250,
            labelWidth: 60,
            queryField: 'Name,FullName,OwnerName',
            emptyText: '模糊搜索所属单位、账户名称'
        }, {
            text: '创建',
            iconCls: 'x-fa fa-user',
            iconAlign: 'left',
            handler: '_onCreateEntity'
        }, {
            text: '明细',
            iconCls: 'x-fa fa-file-text-o',
            iconAlign: 'left',
            handler: '_onReadAccountDetail',
            bind: {
                disabled: '{!_selection}'
            }
        }]
    }, {
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }],
    columnLines: true,
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: false
        },
        items: [{
            xtype: 'rownumberer',
            align: 'center',
            resizable: false
        }, {
            text: '账号名称',
            dataIndex: 'Name',
            sortable: true,
            width: 240
        }, {
            text: '账号',
            dataIndex: 'SerialNumber',
            width: 240
        }, {
            text: '账号所属',
            dataIndex: 'OwnerName',
            sortable: true,
            width: 200
        }, {
            text: '账户余额',
            dataIndex: 'Amount',
            align: 'right',
            resizable: false,
            width: 120,
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            }
        }, {
            text: '授信额度',
            dataIndex: 'CreditLine',
            align: 'right',
            resizable: false,
            renderer: KiviiContext.Const.FinancesFunctionsMoneyToFmoney,
            width: 100
        }, {
            text: '币种单位',
            dataIndex: 'Currency',
            resizable: false,
            sortable: true,
            width: 90,
            renderer: '_renderCurrency'
        }, {
            text: '账户类型',
            dataIndex: 'Type',
            resizable: false,
            sortable: true,
            width: 90,
            renderer: '_renderType'
        }, {
            text: '摘要',
            dataIndex: 'Summary',
            resizable: true,
            width: 150
        }, {
            text: '备注',
            dataIndex: 'Remark',
            resizable: false,
            minWidth: 100,
            flex: 1
        }]
    },
    controller: {
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _renderCurrency: function(_value, _meta, _record, _rowIndex) {
            if (_value === 'CNY') {
                return '人民币';
            }
            if (_value === 'USD') {
                return '美元';
            }
            if (_value === 'EUR') {
                return '欧元';
            }
            return _value;
        },
        _renderType: function(_value, _meta, _record, _rowIndex) {
            if (_value === 'Cash') {
                return '现金账户';
            }
            if (_value === 'Pos') {
                return '刷卡账户';
            }
            if (_value === 'Bank') {
                return '银行账户';
            }
            if (_value === 'Deposit') {
                return '存款账户';
            }
            if (_value === 'Coupon') {
                return '优惠券';
            }
            if (_value === 'StoredCard') {
                return '储值卡';
            }
            if (_value === 'Biz') {
                return '业务账户';
            }
            if (_value === 'Balance') {
                return '系统平衡';
            }
            if (_value === 'Discount') {
                return '折扣账户';
            }
            return _value;
        },
        _onReadAccountDetail: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            if (!_view.selection) {
                Ext.toast('请先选择账户');
                return;
            }
            let _list = Ext.create('App.Control.Kivii.Finances.AccountDetail.List');
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                autoScroll: true,
                iconCls: 'x-fa fa-file-text-o',
                iconAlign: 'left',
                width: 1200,
                height: 700,
                modal: true,
                resizable: false,
                items: [_list]
            });
            _list.setOwner(_view.selection.data);
            _win.show();
            _list.clear();
            _list.setFilter({
                AccountKvid: _view.selection.data.Kvid
            });
            _list.reload();
        },
        _onCreateEntity: function(_ctrl) {
            var _me = this;
            var _view = _me.getView();
            var _entity = {};
            _entity.Type = 'Deposit';
            _entity.Currency = 'CNY';
            _entity.OwnerName = KiviiContext.CurrentMember.DepartmentName;
            _entity.OwnerKvid = KiviiContext.CurrentMember.DepartmentKvid;
            var _form = Ext.create('App.Control.Kivii.Finances.Account.Form');
            var _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                autoScroll: true,
                iconCls: 'x-fa fa-user',
                iconAlign: 'left',
                width: 700,
                height: 300,
                modal: true,
                resizable: false,
                items: [_form]
            });
            _win.show();
            if (_entity.Kvid) {
                _form.readEntity(_entity, true);
            } else {
                _form.newEntity(_entity, false);
            }
            _form.on('entityCreated', function(_ctrl, _entity) {
                _win.close();
                _view.reload();
            });

        }
    }
});