﻿Ext.require('App.Const.Finances');
Ext.define('App.View.Kivii.Finances.Payment.Split.List', {
    extend: 'System.Control.EntityList',
    entityType: 'Kivii.Finances.Entities.Payment',
    xtype: 'App.View.Kivii.Finances.Payment.Split.List',
    dataSource: '/Restful/Kivii.Finances.Entities.Payment/SplitQuery.json',
    title: '到账使用',
    iconCls: 'x-fa fa-spinner',
    filter: {
    	OwnerType:"Department",
        IsBiz: true,
        OperateTimeGreaterThanOrEqualTo: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
        OperateTimeLessThan: new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate() + 1)
    },
    viewModel: {
        data: {
            _selection: null
        }
    },
    bind: {
        selection: '{_selection}'
    },
    store: {
        autoLoad: true,
        pageSize: 800,
        sorters: [{
            property: 'OperateTime',
            direction: 'DESC'
        }]
    },
    selModel: {
        selType: 'checkboxmodel',
        checkboxSelect: true,
        pruneRemoved: false,
        extensible: 'y'
    },
    features: [{
        ftype: 'summary'
    }],
    dockedItems: [{
        xtype: 'pagingtoolbar',
        dock: 'bottom',
        displayInfo: true,
        items: [{
            xtype: 'button',
            labelWidth: 60,
            iconCls: 'x-fa fa-check-square-o',
            bind: {
                text: '已选择{selectionCount}条记录,点击清除',
                hidden: '{selectionCount==0}'
            },
            handler: '_onClearSelections'
        }]
    }, {
        xtype: 'toolbar',
        dock: 'top',
        overflowHandler: 'scroller',
        items: [{
                xtype: 'combo',
                queryMode: 'local',
                displayField: 'displayInfo',
                valueField: 'isBiz',
                value: true,
                editable: false,
                filterPickList: true,
                reference: 'isBiz',
                store: {
                    fields: ['displayInfo', 'isBiz'],
                    data: [{
                        displayInfo: '业务收入',
                        isBiz: true
                    }, {
                        displayInfo: '非业务收入',
                        isBiz: false
                    }]
                },
                triggers: {
                    clear: {
                        weight: 2,
                        cls: 'x-fa fa-times',
                        handler: '_cleanIsBiz'
                    }
                },
                listeners: {
                    select: '_onSelectIsBiz'
                }
            }, {
                xtype: 'datefield',
                fieldLabel: '时间范围  开始',
                format: 'Y-m-d',
                labelWidth: 90,
                width: 220,
                reference: 'startTime',
                editable: false,
                value: new Date(new Date().getFullYear(), new Date().getMonth(), 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            },
            {
                xtype: 'datefield',
                fieldLabel: '结束',
                format: 'Y-m-d',
                labelWidth: 30,
                width: 160,
                reference: 'endTime',
                editable: false,
                value: new Date(new Date().getFullYear(), new Date().getMonth(), new Date().getDate() + 1),
                listeners: {
                    select: '_onSelectMonth'
                }
            }, {
                xtype: 'searchField',
                flex: 1,
                minWidth: 250,
                labelWidth: 60,
                queryField: 'SerialNumber,PayerName,PayerAccountName,PayerAccountSerialNumber',
                // queryField: 'Amount',
                emptyText: '模糊搜索流水号、付款单位、收付款账号或名称',
            }, {
                text: '充值',
                iconCls: 'x-fa fa-sign-in',
                handler: '_onTransfer',
                bind: {
                    disabled: '{!_selection}'
                }
            }, {
                xtype: 'splitbutton',
                text: '撤销认领',
                iconCls: 'x-fa fa-arrow-circle-left',
                handler: '_onSplitCancel',
                menu: [{
                    text: '重新认领',
                    iconCls: 'x-fa fa-arrow-circle-down',
                    type: 'Split',
                    handler: '_onSplit',
                    bind: {
                        disabled: '{!_selection}'
                    }
                }],
                bind: {
                    disabled: '{!_selection}'
                }
            }, {
                text: '使用记录',
                iconCls: 'x-fa fa-sign-in',
                handler: '_onUsedList',
                bind: {
                    disabled: '{!_selection}'
                }
            }
        ]
    }],
    columns: {
        defaults: {
            menuDisabled: true,
            sortable: true
        },
        items: [{
            xtype: 'rownumberer',
            align: 'center',
            resizable: false
        }, {
            text: '流水号',
            dataIndex: 'SerialNumber',
            width: 120
        }, {
            text: '所属部门',
            dataIndex: 'OwnerName',
            renderer: '_renderOwnerName',
            width: 120
        }, {
            text: '付款单位',
            dataIndex: 'PayerName',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return '合计 ￥';
            },
            width: 220
        }, {
            text: '发生金额',
            align: 'right',
            dataIndex: 'Amount',
            renderer: KiviiContext.Const.FinancesFunctionsMoneyToFmoney,
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 110
            // }, {
            //     text: '已认领',
            //     align: 'right',
            //     dataIndex: 'AmountSplited',
            //     renderer: '_renderAmount',
            //     summaryType: 'sum',
            //     summaryRenderer: function(value, summaryData, dataIndex) {
            //         return Ext.String.format('{0}', value.toFixed(2));
            //     },
            //     width: 90
        }, {
            text: '开票金额',
            align: 'right',
            dataIndex: 'AmountInvoice',
            renderer: '_renderAmount',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 100
        }, {
            text: '已用金额',
            align: 'right',
            dataIndex: 'AmountUsed',
            renderer: '_renderAmount',
            summaryType: 'sum',
            summaryRenderer: function(value, summaryData, dataIndex) {
                return Ext.String.format('{0}', value.toFixed(2));
            },
            width: 100
        }, {
            text: '付款类型',
            dataIndex: 'Type',
            renderer: '_renderType',
            width: 100
        }, {
            xtype: 'datecolumn',
            text: '发生日期',
            format: 'Y-m-d H:i',
            dataIndex: 'OperateTime',
            width: 150
        }, {
            text: '操作人',
            dataIndex: 'OperatorName',
            width: 100
        }, {
            text: '摘要',
            dataIndex: 'Summary',
            width: 150
        }, {
            text: '付款银行',
            dataIndex: 'PayerAccountName',
            width: 280
        }, {
            text: '付款账号',
            dataIndex: 'PayerAccountSerialNumber',
            width: 180
        }, {
            text: '备注',
            dataIndex: 'Remark',
            flex: 1
        }]
    },
    listeners: {
        activate: '_onActivate'
    },
    controller: {
        _onClearSelections: function() {
            this.getView().clearSelections();
        },
        _onActivate: function(_ctrl, _eOpts) {
            this.getView().reload();
        },
        _renderOwnerName: function(_value, _meta, _record, _rowIndex) {
            if (_value === null || _value === undefined || _value === '') {
                _meta.style = 'background-color:#FFC0CB';
            }
            return _value;
        },
        _renderAmount: function(_value, _meta, _record, _rowIndex) {
            if (_value === _record.data.Amount) {
                _meta.style = 'background-color:#B4EEB4';
            }
            return KiviiContext.Const.FinancesFunctionsMoneyToFmoney(_value);
        },
        _renderType: function(_value, _meta, _record, _rowIndex) {
            _meta.style = 'background-color:#B4EEB4';
            if (_value === 'UnBiz') {
                _meta.style = 'background-color:#F0E68C';
                return '非业务';
            }
            if (_value === 'Refund') {
                _meta.style = 'background-color:#FFC0CB';
                return '退款';
            }
            if (_value === 'Split') {
                return '业务认领';
            }
            if (_value === 'Pos') {
                return '刷卡';
            }
            if (_value === 'Cash') {
                return '现金';
            }
            if (_value === 'AliPay') {
                return '支付宝';
            }
            if (_value === 'WeChat') {
                return '微信支付';
            }
            return _value;
        },

        _onSelectMonth: function(_ctrl, _time, _eOpts) {
            let _controller = this;
            let _view = _controller.getView();
            let _refs = _controller.getReferences();
            let _startTime = _refs.startTime.value;
            let _endTime = _refs.endTime.value || new Date();
            if (_startTime === null) {
                Ext.toast("请选择开始时间!");
                return;
            }
            if (_startTime > _endTime) {
                Ext.toast("开始日期不能大于结束日期!");
                return;
            }
            delete _view.filter.OperateTimeGreaterThanOrEqualTo;
            delete _view.filter.OperateTimeLessThan;
            _view.filter.OperateTimeGreaterThanOrEqualTo = new Date(_startTime.getFullYear(), _startTime.getMonth(), _startTime.getDate());
            _view.filter.OperateTimeLessThan = new Date(_endTime.getFullYear(), _endTime.getMonth(), _endTime.getDate() + 1);
            _view.reload();
        },
        _onSelectIsBiz: function(_ctrl, _record) {
            let _controller = this;
            let _view = _controller.getView();
            _view.filter.IsBiz = _record.data.isBiz;
            _view.reload();
        },
        _cleanIsBiz: function(_ctrl) {
            _ctrl.setValue('');
            let _controller = this;
            let _view = _controller.getView();
            if (_view.filter === null) _view.setFilter({});
            _view.filter.IsBiz = null;
            _view.reload();
        },
        _onTransfer: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            if (_selecteds.length > 1) {
                Ext.toast("充值时请勿多选!");
                return;
            }
            if (_view.selection.data.AmountUsed === _view.selection.data.Amount) {
                Ext.toast("所选到账,无可用金额!");
                return;
            }
            let _form = Ext.create('App.Control.Kivii.Finances.Payment.Transfer.Form');
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                autoScroll: true,
                width: 600,
                height: 350,
                modal: true,
                resizable: false,
                items: [_form]
            });
            _form.setOwner(_view.selection.data, _ctrl);
            _win.show();
            _form.on('entityTransfer', function(_ctrl, _entity) {
                _win.close();
                _view.reload();
            });
        },
        _onSplit: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _msg = Ext.create('Ext.window.MessageBox', {
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                closeAction: 'destroy'
            });
            _msg.confirm(_ctrl.text, '您确认要重新认领选中的' + _selecteds.length + '条认领记录？<br />注:当前认领只会改变所属部门信息!', _controller._split, _controller);

            return;
        },
        _split: function(_optional) {
            if (_optional !== 'yes') return;
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _splits = [];
            for (let _i = 0; _i < _selecteds.length; _i++) {
                let _item = _selecteds[_i].data;
                if (_item.Type === 'Split') _splits.push(_item.Kvid);
            }
            if (_splits.length <= 0) {
                Ext.toast("请选择正确业务认领类型的到账!");
                return;
            }
            Ext.Ajax.request({
                url: '/Restful/Kivii.Finances.Entities.Payment/MultiSplit.json',
                jsonData: {
                    Kvids: _splits
                },
                success: function(_response) {
                    let _rtns = Ext.decode(_response.responseText);
                    Ext.toast('认领成功！');
                    _view.reload();
                },
                failure: function(_response) {

                }
            });
        },
        _onSplitCancel: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _msg = Ext.create('Ext.window.MessageBox', {
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                closeAction: 'destroy'
            });
            _msg.confirm(_ctrl.text, '您确认要撤销选中的' + _selecteds.length + '条认领记录？<br />注:若要撤销已使用认领,则只会清除所属部门信息!', _controller._splitCancel, _controller);

            return;
        },
        _splitCancel: function(_optional) {
            if (_optional !== 'yes') return;
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            let _splits = [];
            let _unBizs = [];
            let _refunds = [];
            for (let _i = 0; _i < _selecteds.length; _i++) {
                let _item = _selecteds[_i].data;
                if (_item.Type === 'Split') _splits.push(_item.Kvid);
                if (_item.Type === 'UnBiz') _unBizs.push(_item.Kvid);
                if (_item.Type === 'Refund') _refunds.push(_item.Kvid);
            }
            if (_splits.length > 0) {
                Ext.Ajax.request({
                    url: '/Restful/Kivii.Finances.Entities.Payment/SplitCancel.json',
                    jsonData: {
                        Kvids: _splits
                    },
                    success: function(_response) {
                        let _rtns = Ext.decode(_response.responseText);
                        Ext.toast('撤销认领成功！');
                        _view.reload();
                    },
                    failure: function(_response) {

                    }
                });
            }
            if (_unBizs.length > 0) {
                Ext.Ajax.request({
                    url: '/Restful/Kivii.Finances.Entities.Payment/UnBizCancel.json',
                    jsonData: {
                        Kvids: _unBizs
                    },
                    success: function(_response) {
                        let _rtns = Ext.decode(_response.responseText);
                        Ext.toast('撤销非业务成功！');
                        _view.reload();
                    },
                    failure: function(_response) {

                    }
                });
            }
            if (_refunds.length > 0) {
                Ext.Ajax.request({
                    url: '/Restful/Kivii.Finances.Entities.Payment/RefundCancel.json',
                    jsonData: {
                        Kvids: _refunds
                    },
                    success: function(_response) {
                        let _rtns = Ext.decode(_response.responseText);
                        Ext.toast('撤销退款成功！');
                        _view.reload();
                    },
                    failure: function(_response) {

                    }
                });
            }
        },
        _onUsedList: function(_ctrl) {
            let _controller = this;
            let _view = _controller.getView();
            let _vm = _controller.getViewModel();
            let _selecteds = _vm.data.selections || [];
            if (!_view.selection) return;
            if (_selecteds.length <= 0) return;
            if (_selecteds.length > 1) {
                Ext.toast("查看使用记录时请勿多选!");
                return;
            }
            let _form = Ext.create('App.Control.Kivii.Finances.Payment.Used.List', {
                header: false
            });
            let _win = Ext.create('Ext.window.Window', {
                layout: 'fit',
                title: _ctrl.text,
                iconCls: _ctrl.iconCls,
                iconAlign: 'left',
                // header:false,
                autoScroll: true,
                width: 1200,
                height: 650,
                modal: true,
                maximizable: true,
                resizable: true,
                items: [_form]
            });
            _form.setOwner(_view.selection.data, _ctrl);
            _win.show();
            _win.on('close', function(_ctrl, _entity) {
                _view.reload();
            });
        },
    }
});